@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict
 
 import elementy.elements as elements
-from .element import Element
+from elementy.element import Element
 
 
 def make_periodic_table():
@@ -14,4 +14,10 @@ def make_periodic_table():
 
 @dataclass
 class PeriodicTable:
+    """Dataclass representing the periodic table
+
+    :group: elements
+
+    """
+
     elements: Dict[str, Element] = field(default_factory=make_periodic_table)
